@@ -37,45 +37,37 @@
 #include <time.h>
 #include <sys/time.h>
 
+#include <chrono>
+
 #ifndef HAVE_LOCALTIME_R
-# include "localtime_r.h"
+#include "localtime_r.h"
 #endif // HAVE_LOCALTIME_R
 
 #ifndef HAVE_GETTIMEOFDAY
-# include "gettimeofday.h"
+#include "gettimeofday.h"
 #endif // HAVE_GETTIMEOFDAY
 
 #ifndef HAVE_STRPTIME
-# include "strptime.h"
+#include "strptime.h"
 #endif // HAVE_STRPTIME
 
 #ifndef HAVE_TIMEGM
-# include "timegm.h"
+#include "timegm.h"
 #endif // HAVE_TIMEGM
 
 #ifndef HAVE_ASCTIME_R
-# include "asctime_r.h"
+#include "asctime_r.h"
 #endif // HAVE_ASCTIME_R
 
 #ifdef __MINGW32__
-# define suseconds_t uint64_t
+#define suseconds_t uint64_t
 #endif
 
-#ifndef CLOCK_MONOTONIC
-# define CLOCK_MONOTONIC 0
-#endif // !CLOCK_MONOTONIC
-#ifndef HAVE_CLOCK_GETTIME
-# ifdef __MINGW32__
-#   include "clock_gettime_mingw.h"
-# elif HAVE_MACH_ABSOLUTE_TIME
-#   include "clock_gettime_osx.h"
-# else
-#   include "timespec.h"
-#   define clock_gettime(ID, TP) (-1)
-# endif // !__MINGW32__
-#endif // !HAVE_CLOCK_GETTIME
+#ifndef HAVE_A2_STRUCT_TIMESPEC
+#include "timespec.h"
+#endif // !HAVE_A2_STRUCT_TIMESPEC
 
 // Rounding error in millis
-#define A2_DELTA_MILLIS 10
+constexpr auto A2_DELTA_MILLIS = std::chrono::milliseconds(10);
 
 #endif // D_A2TIME_H
